==> prestashop_1.3.2.3.zip: prestashop/modules/statssales/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statssales}prestashop>statssales_45c4b3e103155326596d6ccd2fea0f25'] = 'Commandes et CA';
$_MODULE['<{statssales}prestashop>statssales_09a6e97d1ccb13182c8fd316450dbebf'] = 'Affiche l\'évolution du chiffre d\'affaires et la répartition des commandes par statut';
$_MODULE['<{statssales}prestashop>statssales_b1c94ca2fbc3e78fc30069c8d0f01680'] = 'Tout afficher';
$_MODULE['<{statssales}prestashop>statssales_d7778d0c64b6ba21494c97f77a66885a'] = 'Filtrer';
$_MODULE['<{statssales}prestashop>statssales_a252c24ec397a14367098b74b482d7a0'] = 'Ces graphiques représentent l\'évolution de vos commandes et chiffre d\'affaires pour une période donnée. Ce n\'est pas un outil d\'analyse avancé mais il vous permet toutefois de visualiser la rentabilité de votre boutique en un clin d\'oeil. Vous pouvez également comparer les ventes entre différentes périodes (Noël...). Seules les commandes valides sont inclues dans ces deux graphes.';
$_MODULE['<{statssales}prestashop>statssales_0d6f98eca901ce80817bfe6a475fa45c'] = 'Total des commandes passées';
$_MODULE['<{statssales}prestashop>statssales_4d2aaca86fca7a268ce7b6a512d68fd5'] = 'Total des commandes passées (valides) :';
$_MODULE['<{statssales}prestashop>statssales_667c4007914c8a5d3ffd9f704aea2c3b'] = 'Totales des produits commandés (commandes valides) :';
$_MODULE['<{statssales}prestashop>statssales_ec3e48bb9aa902ba2ad608547fdcbfdc'] = 'Chiffre d\'affaires :';
$_MODULE['<{statssales}prestashop>statssales_0718e1ec4754e199aa9cb4bc43a6ff53'] = 'La répartition des états de commande est représentée ci-dessous.';
$_MODULE['<{statssales}prestashop>statssales_3991390ca135c8c780b4a7d9c7c7daf5'] = 'Aucune commande pour cette période';
$_MODULE['<{statssales}prestashop>statssales_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statssales}prestashop>statssales_cc23e852e21d85a834defe24867e3d05'] = 'Plusieurs statuts de commande';
$_MODULE['<{statssales}prestashop>statssales_1ac658f97c9370fb579beca0d7277d56'] = 'Au sein de votre Back-office, plusieurs statuts de commande sont disponibles : En attente du paiement par chèque, Paiement accepté, Préparation en cours, En cours de livraison, Livré, Annulé, Remboursé, Erreur de paiement, Produits indisponibles et en attente du paiement par virement bancaire.';
$_MODULE['<{statssales}prestashop>statssales_ba3224a4f47de7a622fa8e17236b01e3'] = 'Ces statuts ne peuvent être supprimés depuis le Back-office, cependant vous pouvez en ajouter de nouveaux.';
$_MODULE['<{statssales}prestashop>statssales_58d14111d598ec5174fe85dfebe71c56'] = 'Nombre de commandes et produits commandés';
$_MODULE['<{statssales}prestashop>statssales_7442e29d7d53e549b78d93c46b8cdcfc'] = 'Commandes';
$_MODULE['<{statssales}prestashop>statssales_2e80bb3c2f0ddd12eeb8204ce2906bd0'] = 'Commandes valides';
$_MODULE['<{statssales}prestashop>statssales_37510cd177c278556f1731d0c84fac59'] = 'Produits commandés (commandes valides)';
$_MODULE['<{statssales}prestashop>statssales_14f1c54626d722168ee62dff05ed811e'] = 'Chiffre d\'affaires en';
$_MODULE['<{statssales}prestashop>statssales_33eee7690a8cd62490ed9eeadd47d163'] = 'Pourcentage de commandes par statut';

==> prestashop_1.3.4.0.zip: prestashop/modules/statssales/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statssales}prestashop>statssales_45c4b3e103155326596d6ccd2fea0f25'] = 'Commandes et CA';
$_MODULE['<{statssales}prestashop>statssales_09a6e97d1ccb13182c8fd316450dbebf'] = 'Affiche l\'évolution du chiffre d\'affaires et la répartition des commandes par statut';
$_MODULE['<{statssales}prestashop>statssales_b1c94ca2fbc3e78fc30069c8d0f01680'] = 'Tout afficher';
$_MODULE['<{statssales}prestashop>statssales_d7778d0c64b6ba21494c97f77a66885a'] = 'Filtrer';
$_MODULE['<{statssales}prestashop>statssales_a252c24ec397a14367098b74b482d7a0'] = 'Ces graphiques représentent l\'évolution de vos commandes et chiffre d\'affaires pour une période donnée. Ce n\'est pas un outil d\'analyse avancé mais il vous permet toutefois de visualiser la rentabilité de votre boutique en un clin d\'oeil. Vous pouvez également comparer les ventes entre différentes périodes (Noël...). Seules les commandes valides sont inclues dans ces deux graphes.';
$_MODULE['<{statssales}prestashop>statssales_0d6f98eca901ce80817bfe6a475fa45c'] = 'Total des commandes :';
$_MODULE['<{statssales}prestashop>statssales_4d2aaca86fca7a268ce7b6a512d68fd5'] = 'Total des commandes validées :';
$_MODULE['<{statssales}prestashop>statssales_667c4007914c8a5d3ffd9f704aea2c3b'] = 'Total des produits commandés :';
$_MODULE['<{statssales}prestashop>statssales_ec3e48bb9aa902ba2ad608547fdcbfdc'] = 'Chiffre d\'affaires :';
$_MODULE['<{statssales}prestashop>statssales_0718e1ec4754e199aa9cb4bc43a6ff53'] = 'La répartition des états de commande est représentée ci-dessous.';
$_MODULE['<{statssales}prestashop>statssales_3991390ca135c8c780b4a7d9c7c7daf5'] = 'Aucune commande pour cette période';
$_MODULE['<{statssales}prestashop>statssales_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guide';
$_MODULE['<{statssales}prestashop>statssales_cc23e852e21d85a834defe24867e3d05'] = 'Plusieurs statuts de commande';
$_MODULE['<{statssales}prestashop>statssales_1ac658f97c9370fb579beca0d7277d56'] = 'Au sein de votre Back-office, plusieurs statuts de commande sont disponibles : En attente du paiement par chèque, Paiement accepté, Préparation en cours, En cours de livraison, Livré, Annulé, Remboursé, Erreur de paiement, Produits indisponibles et en attente du paiement par virement bancaire.';
$_MODULE['<{statssales}prestashop>statssales_ba3224a4f47de7a622fa8e17236b01e3'] = 'Ces statuts ne peuvent être supprimés depuis le Back-office, cependant vous pouvez en ajouter de nouveaux.';
$_MODULE['<{statssales}prestashop>statssales_bb7ad89807bf69ddca986c142311f936'] = 'Commandes et produits';
$_MODULE['<{statssales}prestashop>statssales_7442e29d7d53e549b78d93c46b8cdcfc'] = 'Commandes';
$_MODULE['<{statssales}prestashop>statssales_068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_MODULE['<{statssales}prestashop>statssales_14f1c54626d722168ee62dff05ed811e'] = 'Chiffre d\'affaires en';
$_MODULE['<{statssales}prestashop>statssales_33eee7690a8cd62490ed9eeadd47d163'] = 'Pourcentage de commandes par statut';
